@@ -11,6 +11,7 @@ from typing import Iterable, Optional, Any, Dict, List, Sequence, Tuple
 import time
 import struct
 from multiprocessing import Process
+from pathlib import Path
 from functools import partial
 from uuid import uuid1
 import sys
@@ -736,6 +737,9 @@ def main(host, port, max_iters, batch_size, dsn, debug=False):
 
 
 def serve_and_read(filename, port):
+    filename = Path(filename)
+    if not filename.exists():
+        raise FileExistsError(filename)
     dsn = os.getenv("TACVIEW_DSN")
     server_proc = Process(target=partial(
         serve_file.main, filename=filename, port=port))
@@ -747,6 +751,7 @@ def serve_and_read(filename, port):
                     max_iters=None,
                     batch_size=100000,
                     dsn=dsn)
+        server_proc.join()
     except Exception as err:
         LOG.error(err)
     finally:
